﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

using System.IO;

namespace Tree
{
    public partial class Window : Form
    {
        public Window()
        {
            InitializeComponent();
            initTree();
            initList();
            showDirectory (treeView1.Nodes, "c:\\temp");
        }

        private void showDirectory (TreeNodeCollection target, string path)
        {
            DirectoryInfo d = new DirectoryInfo (path);
            TreeNode t = new TreeNode ();
            t.Text = d.Name;
            t.Name = d.FullName;
            t.ToolTipText = d.FullName;
            target.Add (t);

            DirectoryInfo [] dirs = d.GetDirectories();
            foreach (DirectoryInfo v in dirs)
                showDirectory (t.Nodes, v.FullName);

        }

        private void initTree()
        {
            treeView1.ShowNodeToolTips = true;

            TreeNode t = new TreeNode();
            t.Text = "Root";
            t.ToolTipText = "My Tree";
            treeView1.Nodes.Add (t);

            for (int i = 1; i <= 3; i++)
            {
                TreeNode b = new TreeNode();
                b.Text = "Branch " + i;
                b.ImageIndex = i;
                b.SelectedImageIndex = i + 3;
                t.Nodes.Add (b);
            }

            t.ExpandAll ();
        }

        private void initList()
        {
            ListViewItem item = new ListViewItem ();
            item.Text = "abc";
            item.ForeColor = Color.Red;
            listView1.Items.Add (item);
        }

        private void treeView1_AfterSelect(object sender, TreeViewEventArgs e)
        {
            listView1.Items.Clear();
            string path = e.Node.Name;
            if (path != "")
            {
                DirectoryInfo d = new DirectoryInfo (path);
                FileInfo[] files = d.GetFiles ();
                foreach (FileInfo f in files)
                {
                    ListViewItem item = new ListViewItem();
                    item.Text = f.Name;
                    item.Name = f.FullName;
                    item.SubItems.Add(f.Length.ToString ("### ### ### ##0"));
                    item.SubItems.Add(f.LastWriteTime.ToString ("yyyy-MM-dd HH:mm"));
                    listView1.Items.Add(item);
                }
            }
        }

        private void listView1_Click(object sender, EventArgs e)
        {
            if (listView1.SelectedItems.Count == 1)
            {
                ListViewItem item = listView1.SelectedItems [0];
                string path = item.Name;
                if (path != "")
                {
                    FileInfo f = new FileInfo (path);
                    string ext = f.Extension;
                    if (ext == ".bmp" || ext == ".jpg")
                    {
                        pictureBox1.Image = new Bitmap (f.FullName);
                    }
                }
            }
        }
    }
}
